formattools.get_lilypond_command_mark_format_contributions
==========================================================

.. autofunction:: abjad.tools.formattools.get_lilypond_command_mark_format_contributions.get_lilypond_command_mark_format_contributions
